translate.storage.versioncontrol.hg

Package translate :: Package storage :: Package versioncontrol :: Module hg |
[hide private]
[frames] | no frames]

# Module hg

source code

Classes | [hide private]
| hg Class to manage items under revision control of mercurial.

Functions | [hide private]
is_available() check if hg is installed | source code
get_version() return a tuple of (major, minor) for the installed bazaar client | source code

Imports: run_command, GenericRevisionControlSystem